use std::{fs::read_dir, path::PathBuf};

use crate::config::Config;

pub fn find_projects(dir: &PathBuf, config: &Config, depth: usize) -> Option<Vec<PathBuf>> {
    if depth >= config.max_depth {
        return None;
    }

    let Ok(entries) = read_dir(dir) else {
        return None;
    };

    let mut projects = Vec::<PathBuf>::new();
    for entry in entries.flatten() {
        let Some(name) = entry.file_name().into_string().ok() else {
            continue;
        };
        if config.project_marker.contains(&name) {
            return Some(vec![dir.to_path_buf()]);
        }
        let path = entry.path();
        if !path.is_dir() {
            continue;
        }
        let Some(more_projects) = find_projects(&path, config, depth + 1) else {
            continue;
        };
        projects.extend(more_projects);
    }
    Option::Some(projects)
}
