mod config;
mod find;

use crate::config::Config;
use crate::find::find_projects;
use shellexpand::tilde;
use std::{io::Error, path::PathBuf};

fn main() -> Result<(), Error> {
    let config_path = PathBuf::from(tilde("~/.config/ws/config.toml").to_string());
    let config = Config::load(config_path)?;

    let workspace_dir = PathBuf::from(tilde(&config.workspace_directory).to_string());
    let Some(w) = workspace_dir.to_str() else {
		return Ok(());
    };

    let Some(projects) = find_projects(&workspace_dir, &config, 0) else {
        println!("No Projects found");
        return Ok(());
    };
    for project in projects {
        let Some(s) = project.to_str() else {
            continue;
        };
        println!("{:?}",  s.strip_prefix(w));
    }
    Ok(())
}
